@@ -1,4 +1,4 @@
-ERROR_FRAGMENT = '''
+ERROR_FRAGMENT = """
 fragment errorFragment on PythonError {
   message
   className
@@ -14,17 +14,20 @@ fragment errorFragment on PythonError {
     }
   }
 }
-'''
+"""
 
 STEP_EVENT_FRAGMENTS = (
     ERROR_FRAGMENT
-    + '''
+    + """
 fragment metadataEntryFragment on EventMetadataEntry {
   __typename
   label
   description
   ... on EventFloatMetadataEntry {
-    value
+    floatValue
+  }
+  ... on EventIntMetadataEntry {
+    intValue
   }
   ... on EventJsonMetadataEntry {
     jsonString
@@ -144,11 +147,11 @@ fragment stepEventFragment on StepEvent {
 
 
 }
-'''
+"""
 )
 
 MESSAGE_EVENT_FRAGMENTS = (
-    '''
+    """
 fragment messageEventFragment on MessageEvent {
   runId
   message
@@ -161,83 +164,13 @@ fragment messageEventFragment on MessageEvent {
     }
   }
 }
-'''
+"""
     + STEP_EVENT_FRAGMENTS
 )
 
-EXECUTE_RUN_IN_PROCESS_MUTATION = (
-    ERROR_FRAGMENT
-    + '''
-mutation(
-  $repositoryLocationName: String!
-  $repositoryName: String!
-  $runId: String!
-) {
-  executeRunInProcess(
-    repositoryLocationName: $repositoryLocationName
-    repositoryName: $repositoryName
-    runId: $runId
-  ) {
-    __typename
-    ... on ExecuteRunInProcessSuccess {
-      run {
-        runId
-        status
-        pipeline {
-          name
-        }
-
-        tags {
-          key
-          value
-        }
-        runConfigYaml
-        mode
-      }
-    }
-    ... on InvalidStepError {
-      invalidStepKey
-    }
-    ... on InvalidOutputError {
-      stepKey
-      invalidOutputName
-    }
-    ... on PipelineConfigValidationInvalid {
-      pipelineName
-      errors {
-        __typename
-        message
-        path
-        reason
-      }
-    }
-    ... on PipelineNotFoundError {
-      message
-      pipelineName
-    }
-    ... on PythonError {
-      ...errorFragment
-    }
-    ... on PipelineRunConflict {
-      message
-    }
-    ... on PipelineRunNotFoundError {
-      message
-    }
-    ... on ConflictingExecutionParamsError {
-      message
-    }
-    ... on PresetNotFoundError {
-      message
-      preset
-    }
-  }
-}
-'''
-)
 
 EXECUTE_PLAN_MUTATION = (
-    '''
+    """
 mutation(
   $executionParams: ExecutionParams!
   $retries: Retries
@@ -279,11 +212,11 @@ mutation(
     }
   }
 }
-'''
+"""
     + STEP_EVENT_FRAGMENTS
 )
 
-RAW_EXECUTE_PLAN_MUTATION = '''
+RAW_EXECUTE_PLAN_MUTATION = """
 mutation(
   $executionParams: ExecutionParams!
   $retries: Retries
@@ -326,11 +259,11 @@ mutation(
     }
   }
 }
-'''
+"""
 
 SUBSCRIPTION_QUERY = (
     MESSAGE_EVENT_FRAGMENTS
-    + '''
+    + """
 subscription subscribeTest($runId: ID!) {
   pipelineRunLogs(runId: $runId) {
     __typename
@@ -370,12 +303,12 @@ subscription subscribeTest($runId: ID!) {
   }
 }
 
-'''
+"""
 )
 
 LAUNCH_PIPELINE_EXECUTION_MUTATION = (
     ERROR_FRAGMENT
-    + '''
+    + """
 mutation($executionParams: ExecutionParams!) {
   launchPipelineExecution(executionParams: $executionParams) {
     __typename
@@ -427,13 +360,13 @@ mutation($executionParams: ExecutionParams!) {
     }
   }
 }
-'''
+"""
 )
 
 
 LAUNCH_PIPELINE_REEXECUTION_MUTATION = (
     ERROR_FRAGMENT
-    + '''
+    + """
 mutation($executionParams: ExecutionParams!) {
   launchPipelineReexecution(executionParams: $executionParams) {
     __typename
@@ -487,10 +420,10 @@ mutation($executionParams: ExecutionParams!) {
     }
   }
 }
-'''
+"""
 )
 
-PIPELINE_REEXECUTION_INFO_QUERY = '''
+PIPELINE_REEXECUTION_INFO_QUERY = """
 query ReexecutionInfoQuery($runId: ID!) {
   pipelineRunOrError(runId: $runId) {
     __typename
@@ -499,4 +432,42 @@ query ReexecutionInfoQuery($runId: ID!) {
       }
     }
   }
-'''
+"""
+
+LAUNCH_PARTITION_BACKFILL_MUTATION = (
+    ERROR_FRAGMENT
+    + """
+mutation($backfillParams: PartitionBackfillParams!) {
+  launchPartitionBackfill(backfillParams: $backfillParams) {
+    __typename
+    ... on PythonError {
+      ...errorFragment
+    }
+    ... on PartitionSetNotFoundError {
+      message
+    }
+    ... on PartitionBackfillSuccess {
+      backfillId
+      launchedRunIds
+    }
+  }
+}
+"""
+)
+
+LAUNCH_TRIGGERED_EXECUTION = (
+    ERROR_FRAGMENT
+    + """
+mutation($triggerSelector: TriggerSelector!) {
+  triggerExecution(triggerSelector: $triggerSelector) {
+    __typename
+    ... on PythonError {
+      ...errorFragment
+    }
+    ... on TriggerExecutionSuccess {
+      launchedRunIds
+    }
+  }
+}
+  """
+)
