@@ -14,7 +14,7 @@ from graphql.execution.base import ResolveInfo
 from rx import Observable
 
 from dagster import check
-from dagster.core.definitions import ExecutablePipeline
+from dagster.core.definitions import IPipeline
 from dagster.core.definitions.schedule import ScheduleExecutionContext
 from dagster.core.errors import (
     DagsterInvalidConfigError,
@@ -41,32 +41,34 @@ from ..external import (
 from ..pipeline_run_storage import PipelineRunObservableSubscribe
 from ..resume_retry import get_retry_steps_from_execution_plan
 from ..utils import ExecutionParams, UserFacingGraphQLError, capture_dauphin_error
+from .backfill import create_and_launch_partition_backfill
 from .launch_execution import launch_pipeline_execution, launch_pipeline_reexecution
+from .trigger import trigger_execution
 
 
 @capture_dauphin_error
 def terminate_pipeline_execution(graphene_info, run_id):
-    check.inst_param(graphene_info, 'graphene_info', ResolveInfo)
-    check.str_param(run_id, 'run_id')
+    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
+    check.str_param(run_id, "run_id")
 
     instance = graphene_info.context.instance
     run = instance.get_run_by_id(run_id)
 
     if not run:
-        return graphene_info.schema.type_named('PipelineRunNotFoundError')(run_id)
+        return graphene_info.schema.type_named("PipelineRunNotFoundError")(run_id)
 
-    dauphin_run = graphene_info.schema.type_named('PipelineRun')(run)
+    dauphin_run = graphene_info.schema.type_named("PipelineRun")(run)
 
     if run.status != PipelineRunStatus.STARTED:
-        return graphene_info.schema.type_named('TerminatePipelineExecutionFailure')(
+        return graphene_info.schema.type_named("TerminatePipelineExecutionFailure")(
             run=dauphin_run,
-            message='Run {run_id} is not in a started state. Current status is {status}'.format(
+            message="Run {run_id} is not in a started state. Current status is {status}".format(
                 run_id=run.run_id, status=run.status.value
             ),
         )
 
-    can_not_term = graphene_info.schema.type_named('TerminatePipelineExecutionFailure')(
-        run=dauphin_run, message='Unable to terminate run {run_id}'.format(run_id=run.run_id)
+    can_not_term = graphene_info.schema.type_named("TerminatePipelineExecutionFailure")(
+        run=dauphin_run, message="Unable to terminate run {run_id}".format(run_id=run.run_id)
     )
 
     if (
@@ -76,7 +78,7 @@ def terminate_pipeline_execution(graphene_info, run_id):
         if not graphene_info.context.instance.run_launcher.terminate(run_id):
             return can_not_term
 
-        return graphene_info.schema.type_named('TerminatePipelineExecutionSuccess')(dauphin_run)
+        return graphene_info.schema.type_named("TerminatePipelineExecutionSuccess")(dauphin_run)
 
     else:
         return can_not_term
@@ -87,17 +89,17 @@ def delete_pipeline_run(graphene_info, run_id):
     instance = graphene_info.context.instance
 
     if not instance.has_run(run_id):
-        return graphene_info.schema.type_named('PipelineRunNotFoundError')(run_id)
+        return graphene_info.schema.type_named("PipelineRunNotFoundError")(run_id)
 
     instance.delete_run(run_id)
 
-    return graphene_info.schema.type_named('DeletePipelineRunSuccess')(run_id)
+    return graphene_info.schema.type_named("DeletePipelineRunSuccess")(run_id)
 
 
 def get_pipeline_run_observable(graphene_info, run_id, after=None):
-    check.inst_param(graphene_info, 'graphene_info', ResolveInfo)
-    check.str_param(run_id, 'run_id')
-    check.opt_int_param(after, 'after')
+    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
+    check.str_param(run_id, "run_id")
+    check.opt_int_param(after, "after")
     instance = graphene_info.context.instance
     run = instance.get_run_by_id(run_id)
 
@@ -105,8 +107,8 @@ def get_pipeline_run_observable(graphene_info, run_id, after=None):
 
         def _get_error_observable(observer):
             observer.on_next(
-                graphene_info.schema.type_named('PipelineRunLogsSubscriptionFailure')(
-                    missingRunId=run_id, message='Could not load run with id {}'.format(run_id)
+                graphene_info.schema.type_named("PipelineRunLogsSubscriptionFailure")(
+                    missingRunId=run_id, message="Could not load run with id {}".format(run_id)
                 )
             )
 
@@ -116,19 +118,19 @@ def get_pipeline_run_observable(graphene_info, run_id, after=None):
     return Observable.create(
         PipelineRunObservableSubscribe(instance, run_id, after_cursor=after)
     ).map(
-        lambda events: graphene_info.schema.type_named('PipelineRunLogsSubscriptionSuccess')(
-            run=graphene_info.schema.type_named('PipelineRun')(run),
+        lambda events: graphene_info.schema.type_named("PipelineRunLogsSubscriptionSuccess")(
+            run=graphene_info.schema.type_named("PipelineRun")(run),
             messages=[from_event_record(event, run.pipeline_name) for event in events],
         )
     )
 
 
 def get_compute_log_observable(graphene_info, run_id, step_key, io_type, cursor=None):
-    check.inst_param(graphene_info, 'graphene_info', ResolveInfo)
-    check.str_param(run_id, 'run_id')
-    check.str_param(step_key, 'step_key')
-    check.inst_param(io_type, 'io_type', ComputeIOType)
-    check.opt_str_param(cursor, 'cursor')
+    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
+    check.str_param(run_id, "run_id")
+    check.str_param(step_key, "step_key")
+    check.inst_param(io_type, "io_type", ComputeIOType)
+    check.opt_str_param(cursor, "cursor")
 
     return graphene_info.context.instance.compute_log_manager.observable(
         run_id, step_key, io_type, cursor
@@ -137,9 +139,9 @@ def get_compute_log_observable(graphene_info, run_id, step_key, io_type, cursor=
 
 @capture_dauphin_error
 def do_execute_plan(graphene_info, execution_params, retries):
-    check.inst_param(graphene_info, 'graphene_info', ResolveInfo)
-    check.inst_param(execution_params, 'execution_params', ExecutionParams)
-    check.opt_inst_param(retries, 'retries', Retries)
+    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
+    check.inst_param(execution_params, "execution_params", ExecutionParams)
+    check.opt_inst_param(retries, "retries", Retries)
 
     external_pipeline = get_external_pipeline_or_raise(graphene_info, execution_params.selector)
     ensure_valid_config(
@@ -151,10 +153,10 @@ def do_execute_plan(graphene_info, execution_params, retries):
 
 
 def _do_execute_plan(graphene_info, execution_params, external_pipeline, retries):
-    check.inst_param(graphene_info, 'graphene_info', ResolveInfo)
-    check.inst_param(execution_params, 'execution_params', ExecutionParams)
-    check.inst_param(external_pipeline, 'external_pipeline', ExternalPipeline)
-    check.opt_inst_param(retries, 'retries', Retries)
+    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
+    check.inst_param(execution_params, "execution_params", ExecutionParams)
+    check.inst_param(external_pipeline, "external_pipeline", ExternalPipeline)
+    check.opt_inst_param(retries, "retries", Retries)
 
     run_id = execution_params.execution_metadata.run_id
 
@@ -217,7 +219,13 @@ def _do_execute_plan(graphene_info, execution_params, external_pipeline, retries
     def to_graphql_event(event_record):
         return from_dagster_event_record(event_record, external_pipeline.name)
 
-    return graphene_info.schema.type_named('ExecutePlanSuccess')(
+    for event in event_logs:
+        if event.dagster_event.is_pipeline_init_failure:
+            return graphene_info.schema.type_named("PythonError")(
+                event.dagster_event.pipeline_init_failure_data.error
+            )
+
+    return graphene_info.schema.type_named("ExecutePlanSuccess")(
         pipeline=DauphinPipeline(external_pipeline),
         has_failures=any(
             er
