@@ -11,14 +11,15 @@ from dagster.core.host_representation import (
     RepositoryHandle,
     RepositorySelector,
 )
+from dagster.core.storage.tags import TagType, get_tag_type
 
 from .utils import capture_dauphin_error
 
 
 def get_partition_sets_or_error(graphene_info, repository_selector, pipeline_name):
-    check.inst_param(graphene_info, 'graphene_info', ResolveInfo)
-    check.inst_param(repository_selector, 'repository_selector', RepositorySelector)
-    check.str_param(pipeline_name, 'pipeline_name')
+    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
+    check.inst_param(repository_selector, "repository_selector", RepositorySelector)
+    check.str_param(pipeline_name, "pipeline_name")
     location = graphene_info.context.get_repository_location(repository_selector.location_name)
     repository = location.get_repository(repository_selector.repository_name)
     partition_sets = [
@@ -27,9 +28,9 @@ def get_partition_sets_or_error(graphene_info, repository_selector, pipeline_nam
         if partition_set.pipeline_name == pipeline_name
     ]
 
-    return graphene_info.schema.type_named('PartitionSets')(
+    return graphene_info.schema.type_named("PartitionSets")(
         results=[
-            graphene_info.schema.type_named('PartitionSet')(
+            graphene_info.schema.type_named("PartitionSet")(
                 external_repository_handle=repository.handle, external_partition_set=partition_set,
             )
             for partition_set in sorted(
@@ -46,28 +47,28 @@ def get_partition_sets_or_error(graphene_info, repository_selector, pipeline_nam
 
 @capture_dauphin_error
 def get_partition_set(graphene_info, repository_selector, partition_set_name):
-    check.inst_param(graphene_info, 'graphene_info', ResolveInfo)
-    check.inst_param(repository_selector, 'repository_selector', RepositorySelector)
-    check.str_param(partition_set_name, 'partition_set_name')
+    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
+    check.inst_param(repository_selector, "repository_selector", RepositorySelector)
+    check.str_param(partition_set_name, "partition_set_name")
     location = graphene_info.context.get_repository_location(repository_selector.location_name)
     repository = location.get_repository(repository_selector.repository_name)
     partition_sets = repository.get_external_partition_sets()
     for partition_set in partition_sets:
         if partition_set.name == partition_set_name:
-            return graphene_info.schema.type_named('PartitionSet')(
+            return graphene_info.schema.type_named("PartitionSet")(
                 external_repository_handle=repository.handle, external_partition_set=partition_set,
             )
 
-    return graphene_info.schema.type_named('PartitionSetNotFoundError')(partition_set_name)
+    return graphene_info.schema.type_named("PartitionSetNotFoundError")(partition_set_name)
 
 
 @capture_dauphin_error
 def get_partition_by_name(graphene_info, repository_handle, partition_set, partition_name):
-    check.inst_param(graphene_info, 'graphene_info', ResolveInfo)
-    check.inst_param(repository_handle, 'repository_handle', RepositoryHandle)
-    check.inst_param(partition_set, 'partition_set', ExternalPartitionSet)
-    check.str_param(partition_name, 'partition_name')
-    return graphene_info.schema.type_named('Partition')(
+    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
+    check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+    check.inst_param(partition_set, "partition_set", ExternalPartitionSet)
+    check.str_param(partition_name, "partition_name")
+    return graphene_info.schema.type_named("Partition")(
         external_repository_handle=repository_handle,
         external_partition_set=partition_set,
         partition_name=partition_name,
@@ -75,47 +76,48 @@ def get_partition_by_name(graphene_info, repository_handle, partition_set, parti
 
 
 def get_partition_config(graphene_info, repository_handle, partition_set_name, partition_name):
-    check.inst_param(repository_handle, 'repository_handle', RepositoryHandle)
-    check.str_param(partition_set_name, 'partition_set_name')
-    check.str_param(partition_name, 'partition_name')
+    check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+    check.str_param(partition_set_name, "partition_set_name")
+    check.str_param(partition_name, "partition_name")
 
     result = graphene_info.context.get_external_partition_config(
         repository_handle, partition_set_name, partition_name,
     )
 
     if isinstance(result, ExternalPartitionConfigData):
-        return graphene_info.schema.type_named('PartitionRunConfig')(
+        return graphene_info.schema.type_named("PartitionRunConfig")(
             yaml=yaml.safe_dump(result.run_config, default_flow_style=False)
         )
     else:
-        return graphene_info.schema.type_named('PythonError')(result.error)
+        return graphene_info.schema.type_named("PythonError")(result.error)
 
 
 def get_partition_tags(graphene_info, repository_handle, partition_set_name, partition_name):
-    check.inst_param(repository_handle, 'repository_handle', RepositoryHandle)
-    check.str_param(partition_set_name, 'partition_set_name')
-    check.str_param(partition_name, 'partition_name')
+    check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+    check.str_param(partition_set_name, "partition_set_name")
+    check.str_param(partition_name, "partition_name")
 
     result = graphene_info.context.get_external_partition_tags(
         repository_handle, partition_set_name, partition_name
     )
 
     if isinstance(result, ExternalPartitionTagsData):
-        return graphene_info.schema.type_named('PartitionTags')(
+        return graphene_info.schema.type_named("PartitionTags")(
             results=[
-                graphene_info.schema.type_named('PipelineTag')(key=key, value=value)
+                graphene_info.schema.type_named("PipelineTag")(key=key, value=value)
                 for key, value in result.tags.items()
+                if get_tag_type(key) != TagType.HIDDEN
             ]
         )
     else:
-        return graphene_info.schema.type_named('PythonError')(result.error)
+        return graphene_info.schema.type_named("PythonError")(result.error)
 
 
 def get_partitions(
     graphene_info, repository_handle, partition_set, cursor=None, limit=None, reverse=False
 ):
-    check.inst_param(repository_handle, 'repository_handle', RepositoryHandle)
-    check.inst_param(partition_set, 'partition_set', ExternalPartitionSet)
+    check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
+    check.inst_param(partition_set, "partition_set", ExternalPartitionSet)
     result = graphene_info.context.get_external_partition_names(
         repository_handle, partition_set.name
     )
@@ -125,9 +127,9 @@ def get_partitions(
             result.partition_names, cursor, limit, reverse
         )
 
-        return graphene_info.schema.type_named('Partitions')(
+        return graphene_info.schema.type_named("Partitions")(
             results=[
-                graphene_info.schema.type_named('Partition')(
+                graphene_info.schema.type_named("Partition")(
                     external_partition_set=partition_set,
                     external_repository_handle=repository_handle,
                     partition_name=partition_name,
@@ -138,7 +140,7 @@ def get_partitions(
 
     else:
         assert isinstance(result, ExternalPartitionExecutionErrorData)
-        return graphene_info.schema.type_named('PythonError')(result.error)
+        return graphene_info.schema.type_named("PythonError")(result.error)
 
 
 def _apply_cursor_limit_reverse(items, cursor, limit, reverse):
