@@ -15,46 +15,41 @@ from .utils import UserFacingGraphQLError, capture_dauphin_error
 
 @capture_dauphin_error
 def reconcile_scheduler_state(graphene_info, repository_selector):
-    check.inst_param(graphene_info, 'graphene_info', ResolveInfo)
-    check.inst_param(repository_selector, 'repository_selector', RepositorySelector)
+    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
+    check.inst_param(repository_selector, "repository_selector", RepositorySelector)
 
     location = graphene_info.context.get_repository_location(repository_selector.location_name)
     repository = location.get_repository(repository_selector.repository_name)
     instance = graphene_info.context.instance
 
     instance.reconcile_scheduler_state(repository)
-    return graphene_info.schema.type_named('ReconcileSchedulerStateSuccess')(message="Success")
+    return graphene_info.schema.type_named("ReconcileSchedulerStateSuccess")(message="Success")
 
 
 @capture_dauphin_error
 def start_schedule(graphene_info, schedule_selector):
-    check.inst_param(graphene_info, 'graphene_info', ResolveInfo)
-    check.inst_param(schedule_selector, 'schedule_selector', ScheduleSelector)
+    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
+    check.inst_param(schedule_selector, "schedule_selector", ScheduleSelector)
     location = graphene_info.context.get_repository_location(schedule_selector.location_name)
     repository = location.get_repository(schedule_selector.repository_name)
     instance = graphene_info.context.instance
     schedule_state = instance.start_schedule_and_update_storage_state(
         repository.get_external_schedule(schedule_selector.schedule_name)
     )
-    return graphene_info.schema.type_named('ScheduleStateResult')(
-        schedule_state=graphene_info.schema.type_named('ScheduleState')(
+    return graphene_info.schema.type_named("ScheduleStateResult")(
+        schedule_state=graphene_info.schema.type_named("ScheduleState")(
             graphene_info, schedule_state=schedule_state
         )
     )
 
 
 @capture_dauphin_error
-def stop_schedule(graphene_info, schedule_selector):
-    check.inst_param(graphene_info, 'graphene_info', ResolveInfo)
-    check.inst_param(schedule_selector, 'schedule_selector', ScheduleSelector)
-    location = graphene_info.context.get_repository_location(schedule_selector.location_name)
-    repository = location.get_repository(schedule_selector.repository_name)
+def stop_schedule(graphene_info, schedule_origin_id):
+    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
     instance = graphene_info.context.instance
-    schedule_state = instance.stop_schedule_and_update_storage_state(
-        repository.get_external_schedule(schedule_selector.schedule_name).get_origin_id()
-    )
-    return graphene_info.schema.type_named('ScheduleStateResult')(
-        schedule_state=graphene_info.schema.type_named('ScheduleState')(
+    schedule_state = instance.stop_schedule_and_update_storage_state(schedule_origin_id)
+    return graphene_info.schema.type_named("ScheduleStateResult")(
+        schedule_state=graphene_info.schema.type_named("ScheduleState")(
             graphene_info, schedule_state=schedule_state
         )
     )
@@ -65,9 +60,9 @@ def get_scheduler_or_error(graphene_info):
     instance = graphene_info.context.instance
 
     if not instance.scheduler:
-        raise UserFacingGraphQLError(graphene_info.schema.type_named('SchedulerNotDefinedError')())
+        raise UserFacingGraphQLError(graphene_info.schema.type_named("SchedulerNotDefinedError")())
 
-    return graphene_info.schema.type_named('Scheduler')(
+    return graphene_info.schema.type_named("Scheduler")(
         scheduler_class=instance.scheduler.__class__.__name__
     )
 
@@ -76,19 +71,30 @@ def get_scheduler_or_error(graphene_info):
 def get_schedule_states_or_error(
     graphene_info, repository_selector, with_no_schedule_definition_filter=None
 ):
-    check.inst_param(graphene_info, 'graphene_info', ResolveInfo)
-    check.inst_param(repository_selector, 'repository_selector', RepositorySelector)
+    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
+    check.opt_inst_param(repository_selector, "repository_selector", RepositorySelector)
     check.opt_bool_param(
-        with_no_schedule_definition_filter, 'with_no_schedule_definition_filter', default=False
+        with_no_schedule_definition_filter, "with_no_schedule_definition_filter", default=False
     )
 
+    instance = graphene_info.context.instance
+    if not repository_selector:
+        # Return all schedule states
+        results = [
+            graphene_info.schema.type_named("ScheduleState")(
+                graphene_info, schedule_state=schedule_state
+            )
+            for schedule_state in instance.all_stored_schedule_state()
+        ]
+        return graphene_info.schema.type_named("ScheduleStates")(results=results)
+
     location = graphene_info.context.get_repository_location(repository_selector.location_name)
     repository = location.get_repository(repository_selector.repository_name)
     repository_origin_id = repository.get_origin().get_id()
     instance = graphene_info.context.instance
 
     results = [
-        graphene_info.schema.type_named('ScheduleState')(
+        graphene_info.schema.type_named("ScheduleState")(
             graphene_info, schedule_state=schedule_state
         )
         for schedule_state in instance.all_stored_schedule_state(
@@ -112,38 +118,38 @@ def get_schedule_states_or_error(
             )
         )
 
-    return graphene_info.schema.type_named('ScheduleStates')(results=results)
+    return graphene_info.schema.type_named("ScheduleStates")(results=results)
 
 
 @capture_dauphin_error
 def get_schedule_definitions_or_error(graphene_info, repository_selector):
-    check.inst_param(graphene_info, 'graphene_info', ResolveInfo)
-    check.inst_param(repository_selector, 'repository_selector', RepositorySelector)
+    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
+    check.inst_param(repository_selector, "repository_selector", RepositorySelector)
 
     location = graphene_info.context.get_repository_location(repository_selector.location_name)
     repository = location.get_repository(repository_selector.repository_name)
     external_schedules = repository.get_external_schedules()
 
     results = [
-        graphene_info.schema.type_named('ScheduleDefinition')(
+        graphene_info.schema.type_named("ScheduleDefinition")(
             graphene_info, external_schedule=external_schedule
         )
         for external_schedule in external_schedules
     ]
 
-    return graphene_info.schema.type_named('ScheduleDefinitions')(results=results)
+    return graphene_info.schema.type_named("ScheduleDefinitions")(results=results)
 
 
 def get_schedule_definitions_for_pipeline(graphene_info, pipeline_selector):
-    check.inst_param(graphene_info, 'graphene_info', ResolveInfo)
-    check.inst_param(pipeline_selector, 'pipeline_selector', PipelineSelector)
+    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
+    check.inst_param(pipeline_selector, "pipeline_selector", PipelineSelector)
 
     location = graphene_info.context.get_repository_location(pipeline_selector.location_name)
     repository = location.get_repository(pipeline_selector.repository_name)
     external_schedules = repository.get_external_schedules()
 
     return [
-        graphene_info.schema.type_named('ScheduleDefinition')(
+        graphene_info.schema.type_named("ScheduleDefinition")(
             graphene_info, external_schedule=external_schedule
         )
         for external_schedule in external_schedules
@@ -153,26 +159,26 @@ def get_schedule_definitions_for_pipeline(graphene_info, pipeline_selector):
 
 @capture_dauphin_error
 def get_schedule_definition_or_error(graphene_info, schedule_selector):
-    check.inst_param(graphene_info, 'graphene_info', ResolveInfo)
-    check.inst_param(schedule_selector, 'schedule_selector', ScheduleSelector)
+    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
+    check.inst_param(schedule_selector, "schedule_selector", ScheduleSelector)
     location = graphene_info.context.get_repository_location(schedule_selector.location_name)
     repository = location.get_repository(schedule_selector.repository_name)
 
     external_schedule = repository.get_external_schedule(schedule_selector.schedule_name)
     if not external_schedule:
         raise UserFacingGraphQLError(
-            graphene_info.schema.type_named('ScheduleDefinitionNotFoundError')(
+            graphene_info.schema.type_named("ScheduleDefinitionNotFoundError")(
                 schedule_name=schedule_selector.schedule_name
             )
         )
 
-    return graphene_info.schema.type_named('ScheduleDefinition')(
+    return graphene_info.schema.type_named("ScheduleDefinition")(
         graphene_info, external_schedule=external_schedule
     )
 
 
 def get_schedule_config(graphene_info, external_schedule):
-    check.inst_param(external_schedule, 'external_schedule', ExternalSchedule)
+    check.inst_param(external_schedule, "external_schedule", ExternalSchedule)
     handle = external_schedule.handle.repository_handle
 
     result = graphene_info.context.get_external_schedule_execution_data(
@@ -180,8 +186,8 @@ def get_schedule_config(graphene_info, external_schedule):
     )
     if isinstance(result, ExternalScheduleExecutionData):
         run_config_yaml = yaml.safe_dump(result.run_config, default_flow_style=False)
-        return graphene_info.schema.type_named('ScheduleRunConfig')(
-            yaml=run_config_yaml if run_config_yaml else ''
+        return graphene_info.schema.type_named("ScheduleRunConfig")(
+            yaml=run_config_yaml if run_config_yaml else ""
         )
     else:
-        return graphene_info.schema.type_named('PythonError')(result.error)
+        return graphene_info.schema.type_named("PythonError")(result.error)
