@@ -7,16 +7,18 @@ def create_schema():
     # dauphin depends on import-based side effects
     # pylint: disable=W0611
     from . import (
+        assets,
         config_types,
+        dagster_types,
         errors,
         execution,
+        external,
         paging,
+        partition_sets,
         pipelines,
         roots,
         runs,
         schedules,
-        partition_sets,
-        runtime_types,
     )
 
     return dauphin.create_schema()
