@@ -12,6 +12,7 @@ from dagster import PipelineRun, check, seven
 from dagster.core.definitions.events import (
     EventMetadataEntry,
     FloatMetadataEntryData,
+    IntMetadataEntryData,
     JsonMetadataEntryData,
     MarkdownMetadataEntryData,
     PathMetadataEntryData,
@@ -26,20 +27,22 @@ from dagster.core.execution.stats import RunStepKeyStatsSnapshot, StepEventStatu
 from dagster.core.host_representation import ExternalExecutionPlan
 from dagster.core.storage.compute_log_manager import ComputeIOType, ComputeLogFileData
 from dagster.core.storage.pipeline_run import PipelineRunStatsSnapshot, PipelineRunStatus
+from dagster.core.storage.tags import TagType, get_tag_type
 
 DauphinPipelineRunStatus = dauphin.Enum.from_enum(PipelineRunStatus)
 DauphinStepEventStatus = dauphin.Enum.from_enum(StepEventStatus)
+DauphinTagType = dauphin.Enum.from_enum(TagType)
 
 
 class DauphinPipelineOrError(dauphin.Union):
     class Meta(object):
-        name = 'PipelineOrError'
-        types = ('Pipeline', 'PipelineNotFoundError', 'InvalidSubsetError', 'PythonError')
+        name = "PipelineOrError"
+        types = ("Pipeline", "PipelineNotFoundError", "InvalidSubsetError", "PythonError")
 
 
 class DauphinPipelineRunStatsSnapshot(dauphin.ObjectType):
     class Meta(object):
-        name = 'PipelineRunStatsSnapshot'
+        name = "PipelineRunStatsSnapshot"
 
     runId = dauphin.NonNull(dauphin.String)
     stepsSucceeded = dauphin.NonNull(dauphin.Int)
@@ -59,29 +62,29 @@ class DauphinPipelineRunStatsSnapshot(dauphin.ObjectType):
             startTime=stats.start_time,
             endTime=stats.end_time,
         )
-        self._stats = check.inst_param(stats, 'stats', PipelineRunStatsSnapshot)
+        self._stats = check.inst_param(stats, "stats", PipelineRunStatsSnapshot)
 
 
 class DauphinPipelineRunStatsOrError(dauphin.Union):
     class Meta(object):
-        name = 'PipelineRunStatsOrError'
-        types = ('PipelineRunStatsSnapshot', 'PythonError')
+        name = "PipelineRunStatsOrError"
+        types = ("PipelineRunStatsSnapshot", "PythonError")
 
 
 class DauphinPipelineRunStepStats(dauphin.ObjectType):
     class Meta(object):
-        name = 'PipelineRunStepStats'
+        name = "PipelineRunStepStats"
 
     runId = dauphin.NonNull(dauphin.String)
     stepKey = dauphin.NonNull(dauphin.String)
-    status = dauphin.NonNull('StepEventStatus')
+    status = dauphin.Field("StepEventStatus")
     startTime = dauphin.Field(dauphin.Float)
     endTime = dauphin.Field(dauphin.Float)
-    materializations = dauphin.non_null_list('Materialization')
-    expectationResults = dauphin.non_null_list('ExpectationResult')
+    materializations = dauphin.non_null_list("Materialization")
+    expectationResults = dauphin.non_null_list("ExpectationResult")
 
     def __init__(self, stats):
-        self._stats = check.inst_param(stats, 'stats', RunStepKeyStatsSnapshot)
+        self._stats = check.inst_param(stats, "stats", RunStepKeyStatsSnapshot)
         super(DauphinPipelineRunStepStats, self).__init__(
             runId=stats.run_id,
             stepKey=stats.step_key,
@@ -95,39 +98,39 @@ class DauphinPipelineRunStepStats(dauphin.ObjectType):
 
 class DauphinPipelineRun(dauphin.ObjectType):
     class Meta(object):
-        name = 'PipelineRun'
+        name = "PipelineRun"
 
     runId = dauphin.NonNull(dauphin.String)
     # Nullable because of historical runs
     pipelineSnapshotId = dauphin.String()
-    status = dauphin.NonNull('PipelineRunStatus')
-    pipeline = dauphin.NonNull('PipelineReference')
+    status = dauphin.NonNull("PipelineRunStatus")
+    pipeline = dauphin.NonNull("PipelineReference")
     pipelineName = dauphin.NonNull(dauphin.String)
     solidSelection = dauphin.List(dauphin.NonNull(dauphin.String))
-    stats = dauphin.NonNull('PipelineRunStatsOrError')
-    stepStats = dauphin.non_null_list('PipelineRunStepStats')
+    stats = dauphin.NonNull("PipelineRunStatsOrError")
+    stepStats = dauphin.non_null_list("PipelineRunStepStats")
     computeLogs = dauphin.Field(
-        dauphin.NonNull('ComputeLogs'),
+        dauphin.NonNull("ComputeLogs"),
         stepKey=dauphin.Argument(dauphin.NonNull(dauphin.String)),
-        description='''
+        description="""
         Compute logs are the stdout/stderr logs for a given solid step computation
-        ''',
+        """,
     )
-    executionPlan = dauphin.Field('ExecutionPlan')
+    executionPlan = dauphin.Field("ExecutionPlan")
     stepKeysToExecute = dauphin.List(dauphin.NonNull(dauphin.String))
     runConfigYaml = dauphin.NonNull(dauphin.String)
     mode = dauphin.NonNull(dauphin.String)
-    tags = dauphin.non_null_list('PipelineTag')
+    tags = dauphin.non_null_list("PipelineTag")
     rootRunId = dauphin.Field(dauphin.String)
     parentRunId = dauphin.Field(dauphin.String)
     canTerminate = dauphin.NonNull(dauphin.Boolean)
-    assets = dauphin.non_null_list('Asset')
+    assets = dauphin.non_null_list("Asset")
 
     def __init__(self, pipeline_run):
         super(DauphinPipelineRun, self).__init__(
             runId=pipeline_run.run_id, status=pipeline_run.status, mode=pipeline_run.mode
         )
-        self._pipeline_run = check.inst_param(pipeline_run, 'pipeline_run', PipelineRun)
+        self._pipeline_run = check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
 
     def resolve_pipeline(self, graphene_info):
         return get_pipeline_reference_or_raise(graphene_info, self._pipeline_run,)
@@ -148,7 +151,7 @@ class DauphinPipelineRun(dauphin.ObjectType):
         return get_step_stats(graphene_info, self.run_id)
 
     def resolve_computeLogs(self, graphene_info, stepKey):
-        return graphene_info.schema.type_named('ComputeLogs')(runId=self.run_id, stepKey=stepKey)
+        return graphene_info.schema.type_named("ComputeLogs")(runId=self.run_id, stepKey=stepKey)
 
     def resolve_executionPlan(self, graphene_info):
         if not (
@@ -185,8 +188,9 @@ class DauphinPipelineRun(dauphin.ObjectType):
 
     def resolve_tags(self, graphene_info):
         return [
-            graphene_info.schema.type_named('PipelineTag')(key=key, value=value)
+            graphene_info.schema.type_named("PipelineTag")(key=key, value=value)
             for key, value in self._pipeline_run.tags.items()
+            if get_tag_type(key) != TagType.HIDDEN
         ]
 
     def resolve_rootRunId(self, _):
@@ -208,31 +212,31 @@ class DauphinPipelineRun(dauphin.ObjectType):
 
 class DauphinRunGroup(dauphin.ObjectType):
     class Meta(object):
-        name = 'RunGroup'
+        name = "RunGroup"
 
     rootRunId = dauphin.NonNull(dauphin.String)
     runs = dauphin.List(DauphinPipelineRun)
 
     def __init__(self, root_run_id, runs):
-        check.str_param(root_run_id, 'root_run_id')
-        check.list_param(runs, 'runs', DauphinPipelineRun)
+        check.str_param(root_run_id, "root_run_id")
+        check.list_param(runs, "runs", DauphinPipelineRun)
 
         super(DauphinRunGroup, self).__init__(rootRunId=root_run_id, runs=runs)
 
 
 class DauphinLogLevel(dauphin.Enum):
     class Meta(object):
-        name = 'LogLevel'
+        name = "LogLevel"
 
-    CRITICAL = 'CRITICAL'
-    ERROR = 'ERROR'
-    INFO = 'INFO'
-    WARNING = 'WARNING'
-    DEBUG = 'DEBUG'
+    CRITICAL = "CRITICAL"
+    ERROR = "ERROR"
+    INFO = "INFO"
+    WARNING = "WARNING"
+    DEBUG = "DEBUG"
 
     @classmethod
     def from_level(cls, level):
-        check.int_param(level, 'level')
+        check.int_param(level, "level")
         if level == logging.CRITICAL:
             return DauphinLogLevel.CRITICAL
         elif level == logging.ERROR:
@@ -244,17 +248,17 @@ class DauphinLogLevel(dauphin.Enum):
         elif level == logging.DEBUG:
             return DauphinLogLevel.DEBUG
         else:
-            check.failed('Invalid log level: {level}'.format(level=level))
+            check.failed("Invalid log level: {level}".format(level=level))
 
 
 class DauphinComputeLogs(dauphin.ObjectType):
     class Meta(object):
-        name = 'ComputeLogs'
+        name = "ComputeLogs"
 
     runId = dauphin.NonNull(dauphin.String)
     stepKey = dauphin.NonNull(dauphin.String)
-    stdout = dauphin.Field('ComputeLogFile')
-    stderr = dauphin.Field('ComputeLogFile')
+    stdout = dauphin.Field("ComputeLogFile")
+    stderr = dauphin.Field("ComputeLogFile")
 
     def _resolve_compute_log(self, graphene_info, io_type):
         return graphene_info.context.instance.compute_log_manager.read_logs_file(
@@ -270,7 +274,7 @@ class DauphinComputeLogs(dauphin.ObjectType):
 
 class DauphinComputeLogFile(dauphin.ObjectType):
     class Meta(object):
-        name = 'ComputeLogFile'
+        name = "ComputeLogFile"
 
     path = dauphin.NonNull(dauphin.String)
     data = dauphin.Field(
@@ -283,19 +287,19 @@ class DauphinComputeLogFile(dauphin.ObjectType):
 
 class DauphinMessageEvent(dauphin.Interface):
     class Meta(object):
-        name = 'MessageEvent'
+        name = "MessageEvent"
 
     runId = dauphin.NonNull(dauphin.String)
     message = dauphin.NonNull(dauphin.String)
     timestamp = dauphin.NonNull(dauphin.String)
-    level = dauphin.NonNull('LogLevel')
+    level = dauphin.NonNull("LogLevel")
     stepKey = dauphin.Field(dauphin.String)
     solidHandleID = dauphin.Field(dauphin.String)
 
 
 class DauphinEventMetadataEntry(dauphin.Interface):
     class Meta(object):
-        name = 'EventMetadataEntry'
+        name = "EventMetadataEntry"
 
     label = dauphin.NonNull(dauphin.String)
     description = dauphin.String()
@@ -303,7 +307,7 @@ class DauphinEventMetadataEntry(dauphin.Interface):
 
 class DauphinDisplayableEvent(dauphin.Interface):
     class Meta(object):
-        name = 'DisplayableEvent'
+        name = "DisplayableEvent"
 
     label = dauphin.NonNull(dauphin.String)
     description = dauphin.String()
@@ -312,15 +316,15 @@ class DauphinDisplayableEvent(dauphin.Interface):
 
 class DauphinPipelineRunLogsSubscriptionSuccess(dauphin.ObjectType):
     class Meta(object):
-        name = 'PipelineRunLogsSubscriptionSuccess'
+        name = "PipelineRunLogsSubscriptionSuccess"
 
-    run = dauphin.NonNull('PipelineRun')
-    messages = dauphin.non_null_list('PipelineRunEvent')
+    run = dauphin.NonNull("PipelineRun")
+    messages = dauphin.non_null_list("PipelineRunEvent")
 
 
 class DauphinPipelineRunLogsSubscriptionFailure(dauphin.ObjectType):
     class Meta(object):
-        name = 'PipelineRunLogsSubscriptionFailure'
+        name = "PipelineRunLogsSubscriptionFailure"
 
     message = dauphin.NonNull(dauphin.String)
     missingRunId = dauphin.Field(dauphin.String)
@@ -328,7 +332,7 @@ class DauphinPipelineRunLogsSubscriptionFailure(dauphin.ObjectType):
 
 class DauphinPipelineRunLogsSubscriptionPayload(dauphin.Union):
     class Meta(object):
-        name = 'PipelineRunLogsSubscriptionPayload'
+        name = "PipelineRunLogsSubscriptionPayload"
         types = (
             DauphinPipelineRunLogsSubscriptionSuccess,
             DauphinPipelineRunLogsSubscriptionFailure,
@@ -337,53 +341,55 @@ class DauphinPipelineRunLogsSubscriptionPayload(dauphin.Union):
 
 class DauphinMissingRunIdErrorEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'MissingRunIdErrorEvent'
+        name = "MissingRunIdErrorEvent"
 
     invalidRunId = dauphin.NonNull(dauphin.String)
 
 
 class DauphinLogMessageEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'LogMessageEvent'
+        name = "LogMessageEvent"
         interfaces = (DauphinMessageEvent,)
 
 
 class DauphinPipelineEvent(dauphin.Interface):
     class Meta(object):
-        name = 'PipelineEvent'
+        name = "PipelineEvent"
 
     pipelineName = dauphin.NonNull(dauphin.String)
 
 
 class DauphinPipelineStartEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'PipelineStartEvent'
+        name = "PipelineStartEvent"
         interfaces = (DauphinMessageEvent, DauphinPipelineEvent)
 
 
 class DauphinPipelineSuccessEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'PipelineSuccessEvent'
+        name = "PipelineSuccessEvent"
         interfaces = (DauphinMessageEvent, DauphinPipelineEvent)
 
 
 class DauphinPipelineFailureEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'PipelineFailureEvent'
+        name = "PipelineFailureEvent"
         interfaces = (DauphinMessageEvent, DauphinPipelineEvent)
 
+    error = dauphin.Field("PythonError")
+
 
 class DauphinPipelineInitFailureEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'PipelineInitFailureEvent'
+        name = "PipelineInitFailureEvent"
         interfaces = (DauphinMessageEvent, DauphinPipelineEvent)
 
-    error = dauphin.NonNull('PythonError')
+    error = dauphin.NonNull("PythonError")
 
 
 class DauphinStepEvent(dauphin.Interface):
     class Meta(object):
-        name = 'StepEvent'
+        name = "StepEvent"
 
     stepKey = dauphin.Field(dauphin.String)
     solidHandleID = dauphin.Field(dauphin.String)
@@ -391,34 +397,34 @@ class DauphinStepEvent(dauphin.Interface):
 
 class DauphinExecutionStepStartEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'ExecutionStepStartEvent'
+        name = "ExecutionStepStartEvent"
         interfaces = (DauphinMessageEvent, DauphinStepEvent)
 
 
 class DauphinExecutionStepRestartEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'ExecutionStepRestartEvent'
+        name = "ExecutionStepRestartEvent"
         interfaces = (DauphinMessageEvent, DauphinStepEvent)
 
 
 class DauphinExecutionStepUpForRetryEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'ExecutionStepUpForRetryEvent'
+        name = "ExecutionStepUpForRetryEvent"
         interfaces = (DauphinMessageEvent, DauphinStepEvent)
 
-    error = dauphin.NonNull('PythonError')
+    error = dauphin.NonNull("PythonError")
     secondsToWait = dauphin.Field(dauphin.Int)
 
 
 class DauphinExecutionStepSkippedEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'ExecutionStepSkippedEvent'
+        name = "ExecutionStepSkippedEvent"
         interfaces = (DauphinMessageEvent, DauphinStepEvent)
 
 
 class DauphinEventPathMetadataEntry(dauphin.ObjectType):
     class Meta(object):
-        name = 'EventPathMetadataEntry'
+        name = "EventPathMetadataEntry"
         interfaces = (DauphinEventMetadataEntry,)
 
     path = dauphin.NonNull(dauphin.String)
@@ -426,7 +432,7 @@ class DauphinEventPathMetadataEntry(dauphin.ObjectType):
 
 class DauphinEventJsonMetadataEntry(dauphin.ObjectType):
     class Meta(object):
-        name = 'EventJsonMetadataEntry'
+        name = "EventJsonMetadataEntry"
         interfaces = (DauphinEventMetadataEntry,)
 
     jsonString = dauphin.NonNull(dauphin.String)
@@ -434,7 +440,7 @@ class DauphinEventJsonMetadataEntry(dauphin.ObjectType):
 
 class DauphinEventTextMetadataEntry(dauphin.ObjectType):
     class Meta(object):
-        name = 'EventTextMetadataEntry'
+        name = "EventTextMetadataEntry"
         interfaces = (DauphinEventMetadataEntry,)
 
     text = dauphin.NonNull(dauphin.String)
@@ -442,7 +448,7 @@ class DauphinEventTextMetadataEntry(dauphin.ObjectType):
 
 class DauphinEventUrlMetadataEntry(dauphin.ObjectType):
     class Meta(object):
-        name = 'EventUrlMetadataEntry'
+        name = "EventUrlMetadataEntry"
         interfaces = (DauphinEventMetadataEntry,)
 
     url = dauphin.NonNull(dauphin.String)
@@ -450,7 +456,7 @@ class DauphinEventUrlMetadataEntry(dauphin.ObjectType):
 
 class DauphinEventMarkdownMetadataEntry(dauphin.ObjectType):
     class Meta(object):
-        name = 'EventMarkdownMetadataEntry'
+        name = "EventMarkdownMetadataEntry"
         interfaces = (DauphinEventMetadataEntry,)
 
     md_str = dauphin.NonNull(dauphin.String)
@@ -458,7 +464,7 @@ class DauphinEventMarkdownMetadataEntry(dauphin.ObjectType):
 
 class DauphinEventPythonArtifactMetadataEntry(dauphin.ObjectType):
     class Meta(object):
-        name = 'EventPythonArtifactMetadataEntry'
+        name = "EventPythonArtifactMetadataEntry"
         interfaces = (DauphinEventMetadataEntry,)
 
     module = dauphin.NonNull(dauphin.String)
@@ -467,14 +473,22 @@ class DauphinEventPythonArtifactMetadataEntry(dauphin.ObjectType):
 
 class DauphinEventFloatMetadataEntry(dauphin.ObjectType):
     class Meta(object):
-        name = 'EventFloatMetadataEntry'
+        name = "EventFloatMetadataEntry"
         interfaces = (DauphinEventMetadataEntry,)
 
-    value = dauphin.NonNull(dauphin.Float)
+    floatValue = dauphin.NonNull(dauphin.Float)
+
+
+class DauphinEventIntMetadataEntry(dauphin.ObjectType):
+    class Meta(object):
+        name = "EventIntMetadataEntry"
+        interfaces = (DauphinEventMetadataEntry,)
+
+    intValue = dauphin.NonNull(dauphin.Int)
 
 
 def iterate_metadata_entries(metadata_entries):
-    check.list_param(metadata_entries, 'metadata_entries', of_type=EventMetadataEntry)
+    check.list_param(metadata_entries, "metadata_entries", of_type=EventMetadataEntry)
     for metadata_entry in metadata_entries:
         if isinstance(metadata_entry.entry_data, PathMetadataEntryData):
             yield DauphinEventPathMetadataEntry(
@@ -517,12 +531,18 @@ def iterate_metadata_entries(metadata_entries):
             yield DauphinEventFloatMetadataEntry(
                 label=metadata_entry.label,
                 description=metadata_entry.description,
-                value=metadata_entry.entry_data.value,
+                floatValue=metadata_entry.entry_data.value,
+            )
+        elif isinstance(metadata_entry.entry_data, IntMetadataEntryData):
+            yield DauphinEventIntMetadataEntry(
+                label=metadata_entry.label,
+                description=metadata_entry.description,
+                intValue=metadata_entry.entry_data.value,
             )
         else:
             # skip rest for now
             check.not_implemented(
-                '{} unsupported metadata entry for now'.format(type(metadata_entry.entry_data))
+                "{} unsupported metadata entry for now".format(type(metadata_entry.entry_data))
             )
 
 
@@ -532,20 +552,20 @@ def _to_dauphin_metadata_entries(metadata_entries):
 
 class DauphinObjectStoreOperationType(dauphin.Enum):
     class Meta(object):
-        name = 'ObjectStoreOperationType'
+        name = "ObjectStoreOperationType"
 
-    SET_OBJECT = 'SET_OBJECT'
-    GET_OBJECT = 'GET_OBJECT'
-    RM_OBJECT = 'RM_OBJECT'
-    CP_OBJECT = 'CP_OBJECT'
+    SET_OBJECT = "SET_OBJECT"
+    GET_OBJECT = "GET_OBJECT"
+    RM_OBJECT = "RM_OBJECT"
+    CP_OBJECT = "CP_OBJECT"
 
 
 class DauphinObjectStoreOperationResult(dauphin.ObjectType):
     class Meta(object):
-        name = 'ObjectStoreOperationResult'
+        name = "ObjectStoreOperationResult"
         interfaces = (DauphinDisplayableEvent,)
 
-    op = dauphin.NonNull('ObjectStoreOperationType')
+    op = dauphin.NonNull("ObjectStoreOperationType")
 
     def resolve_metadataEntries(self, _graphene_info):
         return _to_dauphin_metadata_entries(self.metadata_entries)  # pylint: disable=no-member
@@ -553,10 +573,10 @@ class DauphinObjectStoreOperationResult(dauphin.ObjectType):
 
 class DauphinMaterialization(dauphin.ObjectType):
     class Meta(object):
-        name = 'Materialization'
+        name = "Materialization"
         interfaces = (DauphinDisplayableEvent,)
 
-    assetKey = dauphin.Field('AssetKey')
+    assetKey = dauphin.Field("AssetKey")
 
     def resolve_metadataEntries(self, _graphene_info):
         return _to_dauphin_metadata_entries(self.metadata_entries)  # pylint: disable=no-member
@@ -567,12 +587,12 @@ class DauphinMaterialization(dauphin.ObjectType):
         if not asset_key:
             return None
 
-        return graphene_info.schema.type_named('AssetKey')(path=asset_key.path)
+        return graphene_info.schema.type_named("AssetKey")(path=asset_key.path)
 
 
 class DauphinExpectationResult(dauphin.ObjectType):
     class Meta(object):
-        name = 'ExpectationResult'
+        name = "ExpectationResult"
         interfaces = (DauphinDisplayableEvent,)
 
     success = dauphin.NonNull(dauphin.Boolean)
@@ -583,7 +603,7 @@ class DauphinExpectationResult(dauphin.ObjectType):
 
 class DauphinTypeCheck(dauphin.ObjectType):
     class Meta(object):
-        name = 'TypeCheck'
+        name = "TypeCheck"
         interfaces = (DauphinDisplayableEvent,)
 
     success = dauphin.NonNull(dauphin.Boolean)
@@ -594,7 +614,7 @@ class DauphinTypeCheck(dauphin.ObjectType):
 
 class DauphinFailureMetadata(dauphin.ObjectType):
     class Meta(object):
-        name = 'FailureMetadata'
+        name = "FailureMetadata"
         interfaces = (DauphinDisplayableEvent,)
 
     def resolve_metadataEntries(self, _graphene_info):
@@ -603,7 +623,7 @@ class DauphinFailureMetadata(dauphin.ObjectType):
 
 class DauphinExecutionStepInputEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'ExecutionStepInputEvent'
+        name = "ExecutionStepInputEvent"
         interfaces = (DauphinMessageEvent, DauphinStepEvent)
 
     input_name = dauphin.NonNull(dauphin.String)
@@ -612,7 +632,7 @@ class DauphinExecutionStepInputEvent(dauphin.ObjectType):
 
 class DauphinExecutionStepOutputEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'ExecutionStepOutputEvent'
+        name = "ExecutionStepOutputEvent"
         interfaces = (DauphinMessageEvent, DauphinStepEvent)
 
     output_name = dauphin.NonNull(dauphin.String)
@@ -621,22 +641,42 @@ class DauphinExecutionStepOutputEvent(dauphin.ObjectType):
 
 class DauphinExecutionStepSuccessEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'ExecutionStepSuccessEvent'
+        name = "ExecutionStepSuccessEvent"
         interfaces = (DauphinMessageEvent, DauphinStepEvent)
 
 
 class DauphinExecutionStepFailureEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'ExecutionStepFailureEvent'
+        name = "ExecutionStepFailureEvent"
         interfaces = (DauphinMessageEvent, DauphinStepEvent)
 
-    error = dauphin.NonNull('PythonError')
-    failureMetadata = dauphin.Field('FailureMetadata')
+    error = dauphin.NonNull("PythonError")
+    failureMetadata = dauphin.Field("FailureMetadata")
+
+
+class DauphinHookCompletedEvent(dauphin.ObjectType):
+    class Meta(object):
+        name = "HookCompletedEvent"
+        interfaces = (DauphinMessageEvent, DauphinStepEvent)
+
+
+class DauphinHookSkippedEvent(dauphin.ObjectType):
+    class Meta(object):
+        name = "HookSkippedEvent"
+        interfaces = (DauphinMessageEvent, DauphinStepEvent)
+
+
+class DauphinHookErroredEvent(dauphin.ObjectType):
+    class Meta(object):
+        name = "HookErroredEvent"
+        interfaces = (DauphinMessageEvent, DauphinStepEvent)
+
+    error = dauphin.NonNull("PythonError")
 
 
 class DauphinStepMaterializationEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'StepMaterializationEvent'
+        name = "StepMaterializationEvent"
         interfaces = (DauphinMessageEvent, DauphinStepEvent)
 
     materialization = dauphin.NonNull(DauphinMaterialization)
@@ -644,7 +684,7 @@ class DauphinStepMaterializationEvent(dauphin.ObjectType):
 
 class DauphinObjectStoreOperationEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'ObjectStoreOperationEvent'
+        name = "ObjectStoreOperationEvent"
         interfaces = (DauphinMessageEvent, DauphinStepEvent)
 
     operation_result = dauphin.NonNull(DauphinObjectStoreOperationResult)
@@ -652,17 +692,17 @@ class DauphinObjectStoreOperationEvent(dauphin.ObjectType):
 
 class DauphinEngineEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'EngineEvent'
+        name = "EngineEvent"
         interfaces = (DauphinMessageEvent, DauphinDisplayableEvent, DauphinStepEvent)
 
-    error = dauphin.Field('PythonError')
+    error = dauphin.Field("PythonError")
     marker_start = dauphin.Field(dauphin.String)
     marker_end = dauphin.Field(dauphin.String)
 
 
 class DauphinStepExpectationResultEvent(dauphin.ObjectType):
     class Meta(object):
-        name = 'StepExpectationResultEvent'
+        name = "StepExpectationResultEvent"
         interfaces = (DauphinMessageEvent, DauphinStepEvent)
 
     expectation_result = dauphin.NonNull(DauphinExpectationResult)
@@ -671,7 +711,7 @@ class DauphinStepExpectationResultEvent(dauphin.ObjectType):
 # Should be a union of all possible events
 class DauphinPipelineRunEvent(dauphin.Union):
     class Meta(object):
-        name = 'PipelineRunEvent'
+        name = "PipelineRunEvent"
         types = (
             DauphinExecutionStepFailureEvent,
             DauphinExecutionStepInputEvent,
@@ -690,12 +730,15 @@ class DauphinPipelineRunEvent(dauphin.Union):
             DauphinStepExpectationResultEvent,
             DauphinStepMaterializationEvent,
             DauphinEngineEvent,
+            DauphinHookCompletedEvent,
+            DauphinHookSkippedEvent,
+            DauphinHookErroredEvent,
         )
 
 
 class DauphinPipelineTag(dauphin.ObjectType):
     class Meta(object):
-        name = 'PipelineTag'
+        name = "PipelineTag"
 
     key = dauphin.NonNull(dauphin.String)
     value = dauphin.NonNull(dauphin.String)
@@ -707,9 +750,9 @@ class DauphinPipelineTag(dauphin.ObjectType):
 def from_dagster_event_record(event_record, pipeline_name):
     # Lots of event types. Pylint thinks there are too many branches
     # pylint: disable=too-many-branches
-    check.inst_param(event_record, 'event_record', EventRecord)
-    check.param_invariant(event_record.is_dagster_event, 'event_record')
-    check.str_param(pipeline_name, 'pipeline_name')
+    check.inst_param(event_record, "event_record", EventRecord)
+    check.param_invariant(event_record.is_dagster_event, "event_record")
+    check.str_param(pipeline_name, "pipeline_name")
 
     # circular ref at module scope
     from .errors import DauphinPythonError
@@ -762,7 +805,13 @@ def from_dagster_event_record(event_record, pipeline_name):
     elif dagster_event.event_type == DagsterEventType.PIPELINE_SUCCESS:
         return DauphinPipelineSuccessEvent(pipelineName=pipeline_name, **basic_params)
     elif dagster_event.event_type == DagsterEventType.PIPELINE_FAILURE:
-        return DauphinPipelineFailureEvent(pipelineName=pipeline_name, **basic_params)
+        return DauphinPipelineFailureEvent(
+            pipelineName=pipeline_name,
+            error=DauphinPythonError(dagster_event.pipeline_failure_data.error)
+            if (dagster_event.pipeline_failure_data and dagster_event.pipeline_failure_data.error)
+            else None,
+            **basic_params
+        )
 
     elif dagster_event.event_type == DagsterEventType.PIPELINE_INIT_FAILURE:
         return DauphinPipelineInitFailureEvent(
@@ -785,19 +834,27 @@ def from_dagster_event_record(event_record, pipeline_name):
             marker_end=dagster_event.engine_event_data.marker_end,
             **basic_params
         )
+    elif dagster_event.event_type == DagsterEventType.HOOK_COMPLETED:
+        return DauphinHookCompletedEvent(**basic_params)
+    elif dagster_event.event_type == DagsterEventType.HOOK_SKIPPED:
+        return DauphinHookSkippedEvent(**basic_params)
+    elif dagster_event.event_type == DagsterEventType.HOOK_ERRORED:
+        return DauphinHookErroredEvent(
+            error=DauphinPythonError(dagster_event.hook_errored_data.error), **basic_params
+        )
     else:
         raise Exception(
-            'Unknown DAGSTER_EVENT type {inner_type} found in logs'.format(
+            "Unknown DAGSTER_EVENT type {inner_type} found in logs".format(
                 inner_type=dagster_event.event_type
             )
         )
 
 
 def from_compute_log_file(graphene_info, file):
-    check.opt_inst_param(file, 'file', ComputeLogFileData)
+    check.opt_inst_param(file, "file", ComputeLogFileData)
     if not file:
         return None
-    return graphene_info.schema.type_named('ComputeLogFile')(
+    return graphene_info.schema.type_named("ComputeLogFile")(
         path=file.path,
         data=file.data,
         cursor=file.cursor,
@@ -807,8 +864,8 @@ def from_compute_log_file(graphene_info, file):
 
 
 def from_event_record(event_record, pipeline_name):
-    check.inst_param(event_record, 'event_record', EventRecord)
-    check.str_param(pipeline_name, 'pipeline_name')
+    check.inst_param(event_record, "event_record", EventRecord)
+    check.str_param(pipeline_name, "pipeline_name")
 
     if event_record.is_dagster_event:
         return from_dagster_event_record(event_record, pipeline_name)
@@ -817,16 +874,16 @@ def from_event_record(event_record, pipeline_name):
 
 
 def construct_basic_params(event_record):
-    check.inst_param(event_record, 'event_record', EventRecord)
+    check.inst_param(event_record, "event_record", EventRecord)
     return {
-        'runId': event_record.run_id,
-        'message': event_record.dagster_event.message
+        "runId": event_record.run_id,
+        "message": event_record.dagster_event.message
         if (event_record.dagster_event and event_record.dagster_event.message)
         else event_record.user_message,
-        'timestamp': int(event_record.timestamp * 1000),
-        'level': DauphinLogLevel.from_level(event_record.level),
-        'stepKey': event_record.step_key,
-        'solidHandleID': event_record.dagster_event.solid_handle.to_string()
+        "timestamp": int(event_record.timestamp * 1000),
+        "level": DauphinLogLevel.from_level(event_record.level),
+        "stepKey": event_record.step_key,
+        "solidHandleID": event_record.dagster_event.solid_handle.to_string()
         if event_record.is_dagster_event and event_record.dagster_event.solid_handle
         else None,
     }
