@@ -1,6 +1,7 @@
 import csv
 import datetime
 import logging
+import os
 import time
 from collections import OrderedDict
 from copy import deepcopy
@@ -51,9 +52,11 @@ from dagster import (
     usable_as_dagster_type,
     weekly_schedule,
 )
+from dagster.cli.workspace import Workspace
+from dagster.core.definitions.decorators import executable
 from dagster.core.definitions.partition import last_empty_partition
 from dagster.core.definitions.reconstructable import ReconstructableRepository
-from dagster.core.host_representation import InProcessRepositoryLocation
+from dagster.core.host_representation import InProcessRepositoryLocation, RepositoryLocationHandle
 from dagster.core.log_manager import coerce_valid_log_level
 from dagster.core.storage.tags import RESUME_RETRY_TAG
 from dagster.utils import file_relative_path, segfault
@@ -61,13 +64,13 @@ from dagster.utils import file_relative_path, segfault
 
 @dagster_type_loader(String)
 def df_input_schema(_context, path):
-    with open(path, 'r') as fd:
+    with open(path, "r") as fd:
         return [OrderedDict(sorted(x.items(), key=lambda x: x[0])) for x in csv.DictReader(fd)]
 
 
 @dagster_type_materializer(String)
 def df_output_schema(_context, path, value):
-    with open(path, 'w') as fd:
+    with open(path, "w") as fd:
         writer = csv.DictWriter(fd, fieldnames=value[0].keys())
         writer.writeheader()
         writer.writerows(rowdicts=value)
@@ -77,73 +80,75 @@ def df_output_schema(_context, path, value):
 
 PoorMansDataFrame = PythonObjectDagsterType(
     python_type=list,
-    name='PoorMansDataFrame',
+    name="PoorMansDataFrame",
     loader=df_input_schema,
     materializer=df_output_schema,
 )
 
 
 def define_test_out_of_process_context(instance):
-    check.inst_param(instance, 'instance', DagsterInstance)
+    check.inst_param(instance, "instance", DagsterInstance)
     return define_out_of_process_context(__file__, "test_repo", instance)
 
 
 def define_test_context(instance):
-    check.inst_param(instance, 'instance', DagsterInstance)
+    check.inst_param(instance, "instance", DagsterInstance)
     return define_context_for_file(__file__, "test_repo", instance)
 
 
 def create_main_recon_repo():
-    return ReconstructableRepository.for_file(__file__, 'test_repo')
+    return ReconstructableRepository.for_file(__file__, "test_repo")
 
 
 def get_main_external_repo():
     return InProcessRepositoryLocation(
         ReconstructableRepository.from_legacy_repository_yaml(
-            file_relative_path(__file__, 'repo.yaml')
+            file_relative_path(__file__, "repo.yaml")
         ),
-    ).get_repository('test_repo')
+    ).get_repository("test_repo")
 
 
 def define_test_snapshot_context():
     return DagsterGraphQLContext(
         instance=DagsterInstance.ephemeral(),
-        locations=[InProcessRepositoryLocation(create_main_recon_repo())],
+        workspace=Workspace(
+            [RepositoryLocationHandle.create_in_process_location(create_main_recon_repo().pointer)]
+        ),
     )
 
 
 def main_repo_location_name():
-    return '<<in_process>>'
+    return "<<in_process>>"
 
 
 def main_repo_name():
-    return 'test_repo'
+    return "test_repo"
 
 
 @lambda_solid(
-    input_defs=[InputDefinition('num', PoorMansDataFrame)],
+    input_defs=[InputDefinition("num", PoorMansDataFrame)],
     output_def=OutputDefinition(PoorMansDataFrame),
 )
 def sum_solid(num):
     sum_df = deepcopy(num)
     for x in sum_df:
-        x['sum'] = int(x['num1']) + int(x['num2'])
+        x["sum"] = int(x["num1"]) + int(x["num2"])
     return sum_df
 
 
 @lambda_solid(
-    input_defs=[InputDefinition('sum_df', PoorMansDataFrame)],
+    input_defs=[InputDefinition("sum_df", PoorMansDataFrame)],
     output_def=OutputDefinition(PoorMansDataFrame),
 )
 def sum_sq_solid(sum_df):
     sum_sq_df = deepcopy(sum_df)
     for x in sum_sq_df:
-        x['sum_sq'] = int(x['sum']) ** 2
+        x["sum_sq"] = int(x["sum"]) ** 2
     return sum_sq_df
 
 
 @solid(
-    input_defs=[InputDefinition('sum_df', PoorMansDataFrame)],
+    input_defs=[InputDefinition("sum_df", PoorMansDataFrame)],
     output_defs=[OutputDefinition(PoorMansDataFrame)],
 )
 def df_expectations_solid(_context, sum_df):
@@ -154,25 +159,25 @@ def df_expectations_solid(_context, sum_df):
 
 def csv_hello_world_solids_config():
     return {
-        'solids': {
-            'sum_solid': {'inputs': {'num': file_relative_path(__file__, '../data/num.csv')}}
+        "solids": {
+            "sum_solid": {"inputs": {"num": file_relative_path(__file__, "../data/num.csv")}}
         }
     }
 
 
 def csv_hello_world_solids_config_fs_storage():
     return {
-        'solids': {
-            'sum_solid': {'inputs': {'num': file_relative_path(__file__, '../data/num.csv')}}
+        "solids": {
+            "sum_solid": {"inputs": {"num": file_relative_path(__file__, "../data/num.csv")}}
         },
-        'storage': {'filesystem': {}},
+        "storage": {"filesystem": {}},
     }
 
 
-@solid(config_schema={'file': Field(String)})
+@solid(config_schema={"file": Field(String)})
 def loop(context):
-    with open(context.solid_config['file'], 'w') as ff:
-        ff.write('yup')
+    with open(context.solid_config["file"], "w") as ff:
+        ff.write("yup")
 
     while True:
         time.sleep(0.1)
@@ -195,18 +200,24 @@ def noop_pipeline():
 
 @solid
 def solid_asset_a(_):
-    yield AssetMaterialization(asset_key='a')
+    yield AssetMaterialization(asset_key="a")
     yield Output(1)
 
 
 @solid
 def solid_asset_b(_, num):
-    yield AssetMaterialization(asset_key='b')
+    yield AssetMaterialization(asset_key="b")
     time.sleep(0.1)
-    yield AssetMaterialization(asset_key='c')
+    yield AssetMaterialization(asset_key="c")
     yield Output(num)
 
 
+@solid
+def solid_partitioned_asset(_):
+    yield AssetMaterialization(asset_key="a", partition="partition_1")
+    yield Output(1)
+
+
 @pipeline
 def single_asset_pipeline():
     solid_asset_a()
@@ -217,16 +228,21 @@ def multi_asset_pipeline():
     solid_asset_b(solid_asset_a())
 
 
+@pipeline
+def partitioned_asset_pipeline():
+    solid_partitioned_asset()
+
+
 @pipeline
 def pipeline_with_expectations():
     @solid(output_defs=[])
     def emit_successful_expectation(_context):
         yield ExpectationResult(
             success=True,
-            label='always_true',
-            description='Successful',
+            label="always_true",
+            description="Successful",
             metadata_entries=[
-                EventMetadataEntry.json(label='data', data={'reason': 'Just because.'})
+                EventMetadataEntry.json(label="data", data={"reason": "Just because."})
             ],
         )
 
@@ -234,16 +250,16 @@ def pipeline_with_expectations():
     def emit_failed_expectation(_context):
         yield ExpectationResult(
             success=False,
-            label='always_false',
-            description='Failure',
+            label="always_false",
+            description="Failure",
             metadata_entries=[
-                EventMetadataEntry.json(label='data', data={'reason': 'Relentless pessimism.'})
+                EventMetadataEntry.json(label="data", data={"reason": "Relentless pessimism."})
             ],
         )
 
     @solid(output_defs=[])
     def emit_successful_expectation_no_metadata(_context):
-        yield ExpectationResult(success=True, label='no_metadata', description='Successful')
+        yield ExpectationResult(success=True, label="no_metadata", description="Successful")
 
     emit_successful_expectation()
     emit_failed_expectation()
@@ -254,9 +270,9 @@ def pipeline_with_expectations():
 def more_complicated_config():
     @solid(
         config_schema={
-            'field_one': Field(String),
-            'field_two': Field(String, is_required=False),
-            'field_three': Field(String, is_required=False, default_value='some_value'),
+            "field_one": Field(String),
+            "field_two": Field(String, is_required=False),
+            "field_three": Field(String, is_required=False, default_value="some_value"),
         }
     )
     def a_solid_with_three_field_config(_context):
@@ -269,18 +285,18 @@ def more_complicated_config():
 @pipeline
 def more_complicated_nested_config():
     @solid(
-        name='a_solid_with_multilayered_config',
+        name="a_solid_with_multilayered_config",
         input_defs=[],
         output_defs=[],
         config_schema={
-            'field_any': Any,
-            'field_one': String,
-            'field_two': Field(String, is_required=False),
-            'field_three': Field(String, is_required=False, default_value='some_value'),
-            'nested_field': {
-                'field_four_str': String,
-                'field_five_int': Int,
-                'field_six_nullable_int_list': Field([Noneable(int)], is_required=False),
+            "field_any": Any,
+            "field_one": String,
+            "field_two": Field(String, is_required=False),
+            "field_three": Field(String, is_required=False, default_value="some_value"),
+            "nested_field": {
+                "field_four_str": String,
+                "field_five_int": Int,
+                "field_six_nullable_int_list": Field([Noneable(int)], is_required=False),
             },
         },
     )
@@ -293,23 +309,23 @@ def more_complicated_nested_config():
 @pipeline(
     preset_defs=[
         PresetDefinition.from_files(
-            name='prod',
+            name="prod",
             config_files=[
-                file_relative_path(__file__, '../environments/csv_hello_world_prod.yaml')
+                file_relative_path(__file__, "../environments/csv_hello_world_prod.yaml")
             ],
         ),
         PresetDefinition.from_files(
-            name='test',
+            name="test",
             config_files=[
-                file_relative_path(__file__, '../environments/csv_hello_world_test.yaml')
+                file_relative_path(__file__, "../environments/csv_hello_world_test.yaml")
             ],
         ),
         PresetDefinition(
-            name='test_inline',
+            name="test_inline",
             run_config={
-                'solids': {
-                    'sum_solid': {
-                        'inputs': {'num': file_relative_path(__file__, '../data/num.csv')}
+                "solids": {
+                    "sum_solid": {
+                        "inputs": {"num": file_relative_path(__file__, "../data/num.csv")}
                     }
                 }
             },
@@ -337,12 +353,12 @@ def solid_that_gets_tags(context):
     return context.pipeline_run.tags
 
 
-@pipeline(tags={'tag_key': 'tag_value'})
+@pipeline(tags={"tag_key": "tag_value"})
 def hello_world_with_tags():
     return solid_that_gets_tags()
 
 
-@solid(name='solid_with_list', input_defs=[], output_defs=[], config_schema=[int])
+@solid(name="solid_with_list", input_defs=[], output_defs=[], config_schema=[int])
 def solid_def(_):
     return None
 
@@ -361,7 +377,7 @@ def csv_hello_world_df_input():
 def no_config_pipeline():
     @lambda_solid
     def return_hello():
-        return 'Hello'
+        return "Hello"
 
     return return_hello()
 
@@ -370,11 +386,11 @@ def no_config_pipeline():
 def no_config_chain_pipeline():
     @lambda_solid
     def return_foo():
-        return 'foo'
+        return "foo"
 
     @lambda_solid
     def return_hello_world(_):
-        return 'Hello World'
+        return "Hello World"
 
     return return_hello_world(return_foo())
 
@@ -383,7 +399,7 @@ def no_config_chain_pipeline():
 def scalar_output_pipeline():
     @lambda_solid(output_def=OutputDefinition(String))
     def return_str():
-        return 'foo'
+        return "foo"
 
     @lambda_solid(output_def=OutputDefinition(Int))
     def return_int():
@@ -395,7 +411,7 @@ def scalar_output_pipeline():
 
     @lambda_solid(output_def=OutputDefinition(Any))
     def return_any():
-        return 'dkjfkdjfe'
+        return "dkjfkdjfe"
 
     return_str()
     return_int()
@@ -407,11 +423,11 @@ def scalar_output_pipeline():
 def pipeline_with_enum_config():
     @solid(
         config_schema=Enum(
-            'TestEnum',
+            "TestEnum",
             [
-                EnumValue(config_value='ENUM_VALUE_ONE', description='An enum value.'),
-                EnumValue(config_value='ENUM_VALUE_TWO', description='An enum value.'),
-                EnumValue(config_value='ENUM_VALUE_THREE', description='An enum value.'),
+                EnumValue(config_value="ENUM_VALUE_ONE", description="An enum value."),
+                EnumValue(config_value="ENUM_VALUE_TWO", description="An enum value."),
+                EnumValue(config_value="ENUM_VALUE_THREE", description="An enum value."),
             ],
         )
     )
@@ -425,14 +441,14 @@ def pipeline_with_enum_config():
 def naughty_programmer_pipeline():
     @lambda_solid
     def throw_a_thing():
-        raise Exception('bad programmer, bad')
+        raise Exception("bad programmer, bad")
 
     return throw_a_thing()
 
 
 @pipeline
 def pipeline_with_invalid_definition_error():
-    @usable_as_dagster_type(name='InputTypeWithoutHydration')
+    @usable_as_dagster_type(name="InputTypeWithoutHydration")
     class InputTypeWithoutHydration(int):
         pass
 
@@ -441,7 +457,7 @@ def pipeline_with_invalid_definition_error():
         return 1
 
     @solid(
-        input_defs=[InputDefinition('some_input', InputTypeWithoutHydration)],
+        input_defs=[InputDefinition("some_input", InputTypeWithoutHydration)],
         output_defs=[OutputDefinition(Int)],
     )
     def fail_subset(_, some_input):
@@ -460,37 +476,37 @@ def multer_resource(init_context):
     return lambda x: x * init_context.resource_config
 
 
-@resource(config_schema={'num_one': Field(Int), 'num_two': Field(Int)})
+@resource(config_schema={"num_one": Field(Int), "num_two": Field(Int)})
 def double_adder_resource(init_context):
     return (
         lambda x: x
-        + init_context.resource_config['num_one']
-        + init_context.resource_config['num_two']
+        + init_context.resource_config["num_one"]
+        + init_context.resource_config["num_two"]
     )
 
 
 @pipeline(
     mode_defs=[
         ModeDefinition(
-            name='add_mode',
-            resource_defs={'op': adder_resource},
-            description='Mode that adds things',
+            name="add_mode",
+            resource_defs={"op": adder_resource},
+            description="Mode that adds things",
         ),
         ModeDefinition(
-            name='mult_mode',
-            resource_defs={'op': multer_resource},
-            description='Mode that multiplies things',
+            name="mult_mode",
+            resource_defs={"op": multer_resource},
+            description="Mode that multiplies things",
         ),
         ModeDefinition(
-            name='double_adder',
-            resource_defs={'op': double_adder_resource},
-            description='Mode that adds two numbers to thing',
+            name="double_adder",
+            resource_defs={"op": double_adder_resource},
+            description="Mode that adds two numbers to thing",
         ),
     ],
     preset_defs=[PresetDefinition.from_files("add", mode="add_mode")],
 )
 def multi_mode_with_resources():
-    @solid(required_resource_keys={'op'})
+    @solid(required_resource_keys={"op"})
     def apply_to_three(context):
         return context.resources.op(3)
 
@@ -502,9 +518,9 @@ def req_resource(_):
     return 1
 
 
-@pipeline(mode_defs=[ModeDefinition(resource_defs={'R1': req_resource})])
+@pipeline(mode_defs=[ModeDefinition(resource_defs={"R1": req_resource})])
 def required_resource_pipeline():
-    @solid(required_resource_keys={'R1'})
+    @solid(required_resource_keys={"R1"})
     def solid_with_required_resource(_):
         return 1
 
@@ -513,12 +529,12 @@ def required_resource_pipeline():
 
 @logger(config_schema=Field(str))
 def foo_logger(init_context):
-    logger_ = logging.Logger('foo')
+    logger_ = logging.Logger("foo")
     logger_.setLevel(coerce_valid_log_level(init_context.logger_config))
     return logger_
 
 
-@logger({'log_level': Field(str), 'prefix': Field(str)})
+@logger({"log_level": Field(str), "prefix": Field(str)})
 def bar_logger(init_context):
     class BarLogger(logging.Logger):
         def __init__(self, name, prefix, *args, **kwargs):
@@ -529,29 +545,29 @@ def bar_logger(init_context):
             msg = self.prefix + msg
             super(BarLogger, self).log(lvl, msg, *args, **kwargs)
 
-    logger_ = BarLogger('bar', init_context.logger_config['prefix'])
-    logger_.setLevel(coerce_valid_log_level(init_context.logger_config['log_level']))
+    logger_ = BarLogger("bar", init_context.logger_config["prefix"])
+    logger_.setLevel(coerce_valid_log_level(init_context.logger_config["log_level"]))
 
 
 @pipeline(
     mode_defs=[
         ModeDefinition(
-            name='foo_mode', logger_defs={'foo': foo_logger}, description='Mode with foo logger'
+            name="foo_mode", logger_defs={"foo": foo_logger}, description="Mode with foo logger"
         ),
         ModeDefinition(
-            name='bar_mode', logger_defs={'bar': bar_logger}, description='Mode with bar logger'
+            name="bar_mode", logger_defs={"bar": bar_logger}, description="Mode with bar logger"
         ),
         ModeDefinition(
-            name='foobar_mode',
-            logger_defs={'foo': foo_logger, 'bar': bar_logger},
-            description='Mode with multiple loggers',
+            name="foobar_mode",
+            logger_defs={"foo": foo_logger, "bar": bar_logger},
+            description="Mode with multiple loggers",
         ),
     ]
 )
 def multi_mode_with_loggers():
     @solid
     def return_six(context):
-        context.log.critical('OMG!')
+        context.log.critical("OMG!")
         return 6
 
     return return_six()
@@ -559,25 +575,25 @@ def multi_mode_with_loggers():
 
 @pipeline
 def composites_pipeline():
-    @lambda_solid(input_defs=[InputDefinition('num', Int)], output_def=OutputDefinition(Int))
+    @lambda_solid(input_defs=[InputDefinition("num", Int)], output_def=OutputDefinition(Int))
     def add_one(num):
         return num + 1
 
-    @lambda_solid(input_defs=[InputDefinition('num')])
+    @lambda_solid(input_defs=[InputDefinition("num")])
     def div_two(num):
         return num / 2
 
-    @composite_solid(input_defs=[InputDefinition('num', Int)], output_defs=[OutputDefinition(Int)])
+    @composite_solid(input_defs=[InputDefinition("num", Int)], output_defs=[OutputDefinition(Int)])
     def add_two(num):
-        return add_one.alias('adder_2')(add_one.alias('adder_1')(num))
+        return add_one.alias("adder_2")(add_one.alias("adder_1")(num))
 
-    @composite_solid(input_defs=[InputDefinition('num', Int)], output_defs=[OutputDefinition(Int)])
+    @composite_solid(input_defs=[InputDefinition("num", Int)], output_defs=[OutputDefinition(Int)])
     def add_four(num):
-        return add_two.alias('adder_2')(add_two.alias('adder_1')(num))
+        return add_two.alias("adder_2")(add_two.alias("adder_1")(num))
 
     @composite_solid
     def div_four(num):
-        return div_two.alias('div_2')(div_two.alias('div_1')(num))
+        return div_two.alias("div_2")(div_two.alias("div_1")(num))
 
     return div_four(add_four())
 
@@ -587,16 +603,17 @@ def materialization_pipeline():
     @solid
     def materialize(_):
         yield AssetMaterialization(
-            asset_key='all_types',
-            description='a materialization with all metadata types',
+            asset_key="all_types",
+            description="a materialization with all metadata types",
             metadata_entries=[
-                EventMetadataEntry.text('text is cool', 'text'),
-                EventMetadataEntry.url('https://bigty.pe/neato', 'url'),
-                EventMetadataEntry.fspath('/tmp/awesome', 'path'),
-                EventMetadataEntry.json({'is_dope': True}, 'json'),
-                EventMetadataEntry.python_artifact(EventMetadataEntry, 'python class'),
-                EventMetadataEntry.python_artifact(file_relative_path, 'python function'),
-                EventMetadataEntry.float(1.2, 'float'),
+                EventMetadataEntry.text("text is cool", "text"),
+                EventMetadataEntry.url("https://bigty.pe/neato", "url"),
+                EventMetadataEntry.fspath("/tmp/awesome", "path"),
+                EventMetadataEntry.json({"is_dope": True}, "json"),
+                EventMetadataEntry.python_artifact(EventMetadataEntry, "python class"),
+                EventMetadataEntry.python_artifact(file_relative_path, "python function"),
+                EventMetadataEntry.float(1.2, "float"),
+                EventMetadataEntry.int(1, "int"),
             ],
         )
         yield Output(None)
@@ -608,37 +625,37 @@ def materialization_pipeline():
 def spew_pipeline():
     @solid
     def spew(_):
-        print('HELLO WORLD')  # pylint: disable=print-call
+        print("HELLO WORLD")  # pylint: disable=print-call
 
     spew()
 
 
 def retry_config(count):
     return {
-        'resources': {'retry_count': {'config': {'count': count}}},
-        'storage': {'filesystem': {}},
+        "resources": {"retry_count": {"config": {"count": count}}},
+        "storage": {"filesystem": {}},
     }
 
 
-@resource(config_schema={'count': Field(Int, is_required=False, default_value=0)})
+@resource(config_schema={"count": Field(Int, is_required=False, default_value=0)})
 def retry_config_resource(context):
-    return context.resource_config['count']
+    return context.resource_config["count"]
 
 
-@pipeline(mode_defs=[ModeDefinition(resource_defs={'retry_count': retry_config_resource})])
+@pipeline(mode_defs=[ModeDefinition(resource_defs={"retry_count": retry_config_resource})])
 def eventually_successful():
     @solid(output_defs=[OutputDefinition(Int)])
     def spawn(_):
         return 0
 
     @solid(
-        input_defs=[InputDefinition('depth', Int)],
+        input_defs=[InputDefinition("depth", Int)],
         output_defs=[OutputDefinition(Int)],
-        required_resource_keys={'retry_count'},
+        required_resource_keys={"retry_count"},
     )
     def fail(context, depth):
         if context.resources.retry_count <= depth:
-            raise Exception('fail')
+            raise Exception("fail")
 
         return depth + 1
 
@@ -652,15 +669,15 @@ def eventually_successful():
 @pipeline
 def hard_failer():
     @solid(
-        config_schema={'fail': Field(Bool, is_required=False, default_value=False)},
+        config_schema={"fail": Field(Bool, is_required=False, default_value=False)},
         output_defs=[OutputDefinition(Int)],
     )
     def hard_fail_or_0(context):
-        if context.solid_config['fail']:
+        if context.solid_config["fail"]:
             segfault()
         return 0
 
-    @solid(input_defs=[InputDefinition('n', Int)],)
+    @solid(input_defs=[InputDefinition("n", Int)],)
     def increment(_, n):
         return n + 1
 
@@ -669,54 +686,54 @@ def hard_failer():
 
 @resource
 def resource_a(_):
-    return 'A'
+    return "A"
 
 
 @resource
 def resource_b(_):
-    return 'B'
+    return "B"
 
 
-@solid(required_resource_keys={'a'})
+@solid(required_resource_keys={"a"})
 def start(context):
-    assert context.resources.a == 'A'
+    assert context.resources.a == "A"
     return 1
 
 
-@solid(required_resource_keys={'b'})
+@solid(required_resource_keys={"b"})
 def will_fail(context, num):  # pylint: disable=unused-argument
-    assert context.resources.b == 'B'
-    raise Exception('fail')
+    assert context.resources.b == "B"
+    raise Exception("fail")
 
 
-@pipeline(mode_defs=[ModeDefinition(resource_defs={'a': resource_a, 'b': resource_b})])
+@pipeline(mode_defs=[ModeDefinition(resource_defs={"a": resource_a, "b": resource_b})])
 def retry_resource_pipeline():
     will_fail(start())
 
 
 @solid(
-    config_schema={'fail': bool},
-    input_defs=[InputDefinition('inp', str)],
+    config_schema={"fail": bool},
+    input_defs=[InputDefinition("inp", str)],
     output_defs=[
-        OutputDefinition(str, 'start_fail', is_required=False),
-        OutputDefinition(str, 'start_skip', is_required=False),
+        OutputDefinition(str, "start_fail", is_required=False),
+        OutputDefinition(str, "start_skip", is_required=False),
     ],
 )
 def can_fail(context, inp):  # pylint: disable=unused-argument
-    if context.solid_config['fail']:
-        raise Exception('blah')
+    if context.solid_config["fail"]:
+        raise Exception("blah")
 
-    yield Output('okay perfect', 'start_fail')
+    yield Output("okay perfect", "start_fail")
 
 
 @solid(
     output_defs=[
-        OutputDefinition(str, 'success', is_required=False),
-        OutputDefinition(str, 'skip', is_required=False),
+        OutputDefinition(str, "success", is_required=False),
+        OutputDefinition(str, "skip", is_required=False),
     ],
 )
 def multi(_):
-    yield Output('okay perfect', 'success')
+    yield Output("okay perfect", "success")
 
 
 @solid
@@ -724,7 +741,7 @@ def passthrough(_, value):
     return value
 
 
-@solid(input_defs=[InputDefinition('start', Nothing)], output_defs=[])
+@solid(input_defs=[InputDefinition("start", Nothing)], output_defs=[])
 def no_output(_):
     yield ExpectationResult(True)
 
@@ -733,16 +750,16 @@ def no_output(_):
 def retry_multi_output_pipeline():
     multi_success, multi_skip = multi()
     fail, skip = can_fail(multi_success)
-    no_output.alias('child_multi_skip')(multi_skip)
-    no_output.alias('child_skip')(skip)
-    no_output.alias('grandchild_fail')(passthrough.alias('child_fail')(fail))
+    no_output.alias("child_multi_skip")(multi_skip)
+    no_output.alias("child_skip")(skip)
+    no_output.alias("grandchild_fail")(passthrough.alias("child_fail")(fail))
 
 
-@pipeline(tags={'foo': 'bar'})
+@pipeline(tags={"foo": "bar"})
 def tagged_pipeline():
     @lambda_solid
     def simple_solid():
-        return 'Hello'
+        return "Hello"
 
     return simple_solid()
 
@@ -754,29 +771,29 @@ def retry_multi_input_early_terminate_pipeline():
         return 1
 
     @solid(
-        config_schema={'wait_to_terminate': bool},
-        input_defs=[InputDefinition('one', Int)],
+        config_schema={"wait_to_terminate": bool},
+        input_defs=[InputDefinition("one", Int)],
         output_defs=[OutputDefinition(Int)],
     )
     def get_input_one(context, one):
-        if context.solid_config['wait_to_terminate']:
+        if context.solid_config["wait_to_terminate"]:
             while True:
                 time.sleep(0.1)
         return one
 
     @solid(
-        config_schema={'wait_to_terminate': bool},
-        input_defs=[InputDefinition('one', Int)],
+        config_schema={"wait_to_terminate": bool},
+        input_defs=[InputDefinition("one", Int)],
         output_defs=[OutputDefinition(Int)],
     )
     def get_input_two(context, one):
-        if context.solid_config['wait_to_terminate']:
+        if context.solid_config["wait_to_terminate"]:
             while True:
                 time.sleep(0.1)
         return one
 
     @lambda_solid(
-        input_defs=[InputDefinition('input_one', Int), InputDefinition('input_two', Int)],
+        input_defs=[InputDefinition("input_one", Int), InputDefinition("input_two", Int)],
         output_def=OutputDefinition(Int),
     )
     def sum_inputs(input_one, input_two):
@@ -787,26 +804,26 @@ def retry_multi_input_early_terminate_pipeline():
 
 
 def get_retry_multi_execution_params(graphql_context, should_fail, retry_id=None):
-    selector = infer_pipeline_selector(graphql_context, 'retry_multi_output_pipeline')
+    selector = infer_pipeline_selector(graphql_context, "retry_multi_output_pipeline")
     return {
-        'mode': 'default',
-        'selector': selector,
-        'runConfigData': {
-            'storage': {'filesystem': {}},
-            'solids': {'can_fail': {'config': {'fail': should_fail}}},
+        "mode": "default",
+        "selector": selector,
+        "runConfigData": {
+            "storage": {"filesystem": {}},
+            "solids": {"can_fail": {"config": {"fail": should_fail}}},
         },
-        'executionMetadata': {
-            'rootRunId': retry_id,
-            'parentRunId': retry_id,
-            'tags': [{'key': RESUME_RETRY_TAG, 'value': 'true'}],
+        "executionMetadata": {
+            "rootRunId": retry_id,
+            "parentRunId": retry_id,
+            "tags": [{"key": RESUME_RETRY_TAG, "value": "true"}],
         },
     }
 
 
 def define_schedules():
     integer_partition_set = PartitionSetDefinition(
-        name='scheduled_integer_partitions',
-        pipeline_name='no_config_pipeline',
+        name="scheduled_integer_partitions",
+        pipeline_name="no_config_pipeline",
         partition_fn=lambda: [Partition(x) for x in range(1, 10)],
         run_config_fn_for_partition=lambda _partition: {"storage": {"filesystem": {}}},
         tags_fn_for_partition=lambda _partition: {"test": "1234"},
@@ -852,7 +869,7 @@ def define_schedules():
     )
 
     @daily_schedule(
-        pipeline_name='no_config_pipeline',
+        pipeline_name="no_config_pipeline",
         start_date=datetime.datetime.now() - datetime.timedelta(days=1),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=2)).time(),
     )
@@ -860,53 +877,53 @@ def define_schedules():
         return {"storage": {"filesystem": {}}}
 
     @daily_schedule(
-        pipeline_name='multi_mode_with_loggers',
+        pipeline_name="multi_mode_with_loggers",
         start_date=datetime.datetime.now() - datetime.timedelta(days=1),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=2)).time(),
-        mode='foo_mode',
+        mode="foo_mode",
     )
     def partition_based_multi_mode_decorator(_date):
         return {"storage": {"filesystem": {}}}
 
     @hourly_schedule(
-        pipeline_name='no_config_chain_pipeline',
+        pipeline_name="no_config_chain_pipeline",
         start_date=datetime.datetime.now() - datetime.timedelta(days=1),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=2)).time(),
-        solid_selection=['return_foo'],
+        solid_selection=["return_foo"],
     )
     def solid_selection_hourly_decorator(_date):
         return {"storage": {"filesystem": {}}}
 
     @daily_schedule(
-        pipeline_name='no_config_chain_pipeline',
+        pipeline_name="no_config_chain_pipeline",
         start_date=datetime.datetime.now() - datetime.timedelta(days=2),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=3)).time(),
-        solid_selection=['return_foo'],
+        solid_selection=["return_foo"],
     )
     def solid_selection_daily_decorator(_date):
         return {"storage": {"filesystem": {}}}
 
     @monthly_schedule(
-        pipeline_name='no_config_chain_pipeline',
+        pipeline_name="no_config_chain_pipeline",
         start_date=datetime.datetime.now() - datetime.timedelta(days=100),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=4)).time(),
-        solid_selection=['return_foo'],
+        solid_selection=["return_foo"],
     )
     def solid_selection_monthly_decorator(_date):
         return {"storage": {"filesystem": {}}}
 
     @weekly_schedule(
-        pipeline_name='no_config_chain_pipeline',
+        pipeline_name="no_config_chain_pipeline",
         start_date=datetime.datetime.now() - datetime.timedelta(days=50),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=5)).time(),
-        solid_selection=['return_foo'],
+        solid_selection=["return_foo"],
     )
     def solid_selection_weekly_decorator(_date):
         return {"storage": {"filesystem": {}}}
 
     # Schedules for testing the user error boundary
     @daily_schedule(
-        pipeline_name='no_config_pipeline',
+        pipeline_name="no_config_pipeline",
         start_date=datetime.datetime.now() - datetime.timedelta(days=1),
         should_execute=lambda _: asdf,  # pylint: disable=undefined-variable
     )
@@ -914,7 +931,7 @@ def define_schedules():
         return {"storage": {"filesystem": {}}}
 
     @daily_schedule(
-        pipeline_name='no_config_pipeline',
+        pipeline_name="no_config_pipeline",
         start_date=datetime.datetime.now() - datetime.timedelta(days=1),
         tags_fn_for_date=lambda _: asdf,  # pylint: disable=undefined-variable
     )
@@ -922,7 +939,7 @@ def define_schedules():
         return {"storage": {"filesystem": {}}}
 
     @daily_schedule(
-        pipeline_name='no_config_pipeline',
+        pipeline_name="no_config_pipeline",
         start_date=datetime.datetime.now() - datetime.timedelta(days=1),
     )
     def run_config_error_schedule(_date):
@@ -940,14 +957,14 @@ def define_schedules():
         cron_schedule="0 0 * * *",
         pipeline_name="tagged_pipeline",
         run_config={"storage": {"filesystem": {}}},
-        tags={'foo': 'notbar'},
+        tags={"foo": "notbar"},
     )
 
     invalid_config_schedule = ScheduleDefinition(
         name="invalid_config_schedule",
         cron_schedule="0 0 * * *",
         pipeline_name="pipeline_with_enum_config",
-        run_config={"solids": {"takes_an_enum": {'config': "invalid"}}},
+        run_config={"solids": {"takes_an_enum": {"config": "invalid"}}},
     )
 
     return [
@@ -976,11 +993,11 @@ def define_partitions():
     integer_set = PartitionSetDefinition(
         name="integer_partition",
         pipeline_name="no_config_pipeline",
-        solid_selection=['return_hello'],
+        solid_selection=["return_hello"],
         mode="default",
         partition_fn=lambda: [Partition(i) for i in range(10)],
         run_config_fn_for_partition=lambda _: {"storage": {"filesystem": {}}},
-        tags_fn_for_partition=lambda partition: {'foo': partition.name},
+        tags_fn_for_partition=lambda partition: {"foo": partition.name},
     )
 
     enum_set = PartitionSetDefinition(
@@ -990,7 +1007,43 @@ def define_partitions():
         run_config_fn_for_partition=lambda _: {"storage": {"filesystem": {}}},
     )
 
-    return [integer_set, enum_set]
+    chained_partition_set = PartitionSetDefinition(
+        name="chained_integer_partition",
+        pipeline_name="chained_failure_pipeline",
+        mode="default",
+        partition_fn=lambda: [Partition(i) for i in range(10)],
+        run_config_fn_for_partition=lambda _: {"storage": {"filesystem": {}}},
+    )
+
+    return [integer_set, enum_set, chained_partition_set]
+
+
+def define_executables():
+    @executable(pipeline_name="no_config_pipeline")
+    def executable_no_config(_):
+        return {"storage": {"filesystem": {}}}
+
+    return [executable_no_config]
+
+
+@pipeline
+def chained_failure_pipeline():
+    @lambda_solid
+    def always_succeed():
+        return "hello"
+
+    @lambda_solid
+    def conditionally_fail(_):
+        if os.environ.get("TEST_SOLID_SHOULD_FAIL"):
+            raise Exception("blah")
+
+        return "hello"
+
+    @lambda_solid
+    def after_failure(_):
+        return "world"
+
+    return after_failure(conditionally_fail(always_succeed()))
 
 
 @repository
@@ -1021,6 +1074,7 @@ def test_repo():
             no_config_chain_pipeline,
             no_config_pipeline,
             noop_pipeline,
+            partitioned_asset_pipeline,
             pipeline_with_enum_config,
             pipeline_with_expectations,
             pipeline_with_invalid_definition_error,
@@ -1033,7 +1087,9 @@ def test_repo():
             single_asset_pipeline,
             spew_pipeline,
             tagged_pipeline,
+            chained_failure_pipeline,
         ]
         + define_schedules()
         + define_partitions()
+        + define_executables()
     )
